@@ -18,15 +18,16 @@
 #include <cstdint>
 #include <string>
 #include <vector>
+#include <fcitx-utils/fcitxutils_export.h>
 #include <fcitx-utils/flags.h>
 #include <fcitx-utils/keysym.h>
-#include "fcitxutils_export.h"
+#include <fcitx-utils/macros.h>
 
 namespace fcitx {
 class Key;
-typedef FcitxKeySym KeySym;
-typedef Flags<KeyState> KeyStates;
-typedef std::vector<Key> KeyList;
+using KeySym = FcitxKeySym;
+using KeyStates = Flags<KeyState>;
+using KeyList = std::vector<Key>;
 
 /// Control the behavior of toString function.
 enum class KeyStringFormat {
@@ -144,6 +145,9 @@ public:
     /// Check if states has modifier.
     bool hasModifier() const;
 
+    /// Check if states has virtual bit
+    bool isVirtual() const;
+
     /// \brief Normalize a key, usually used when key is from frontend.
     ///
     /// states will be filtered to have only ctrl alt shift and super.
@@ -197,11 +201,11 @@ public:
     /// Convert a key list to string.
     template <typename Container>
     static std::string
-    keyListToString(Container container,
+    keyListToString(const Container &container,
                     KeyStringFormat format = KeyStringFormat::Portable) {
         std::string result;
         bool first = true;
-        for (auto k : container) {
+        for (const auto &k : container) {
             if (first) {
                 first = false;
             } else {
@@ -236,7 +240,7 @@ public:
         if (idx == c.size()) {
             return -1;
         }
-        return idx;
+        return static_cast<int>(idx);
     }
 
 private:
