@@ -6,6 +6,8 @@
  */
 
 #include "log.h"
+#include <charconv>
+#include <chrono>
 #include <cstdlib>
 #include <exception>
 #include <iostream>
@@ -13,19 +15,15 @@
 #include <mutex>
 #include <ostream>
 #include <string>
+#include <system_error>
 #include <type_traits>
 #include <unordered_set>
 #include <utility>
 #include <vector>
-#include <fmt/format.h>
+#include <format>
 #include "macros.h"
 #include "stringutils.h"
 
-#if FMT_VERSION >= 50300
-#include <chrono>
-#include <fmt/chrono.h>
-#endif
-
 namespace fcitx {
 
 namespace {
@@ -174,13 +172,13 @@ void Log::setLogRule(const std::string &ruleString) {
             continue;
         }
         auto &name = ruleItem[0];
-        try {
-            auto level = std::stoi(ruleItem[1]);
+        int level;
+        if (std::from_chars(ruleItem[1].data(),
+                            ruleItem[1].data() + ruleItem[1].size(), level)
+                .ec == std::errc()) {
             if (validateLogLevel(level)) {
                 parsedRules.emplace_back(name, static_cast<LogLevel>(level));
             }
-        } catch (const std::exception &) {
-            continue;
         }
     }
     LogRegistry::instance().setLogRules(parsedRules);
@@ -215,20 +213,23 @@ LogMessageBuilder::LogMessageBuilder(std::ostream &out, LogLevel l,
         break;
     }
 
-#if FMT_VERSION >= 50300
     if (globalLogConfig.showTimeDate) {
         try {
-            auto now = std::chrono::system_clock::now();
-            auto floor = std::chrono::floor<std::chrono::seconds>(now);
-            auto micro = std::chrono::duration_cast<std::chrono::microseconds>(
-                now - floor);
-            auto t = fmt::localtime(std::chrono::system_clock::to_time_t(now));
-            auto timeString = fmt::format("{:%F %T}.{:06d}", t, micro.count());
+            auto now = std::chrono::time_point_cast<std::chrono::microseconds>(
+                std::chrono::system_clock::now());
+#if __cpp_lib_chrono >= 201907L
+            auto current_zone = std::chrono::current_zone();
+            std::chrono::zoned_time zoned_time{current_zone, now};
+
+            auto timeString = std::format("{:%F %T}", zoned_time);
+#else
+            auto timeString = std::format("{:%F %T}", now);
+#endif
             out_ << timeString << " ";
         } catch (...) {
         }
     }
-#endif
+
     out_ << filename << ":" << lineNumber << "] ";
 }
 
