@@ -1,16 +1,21 @@
-#ifndef WL_TOUCH
-#define WL_TOUCH
+#ifndef WL_TOUCH_H_
+#define WL_TOUCH_H_
+#include <cstdint>
 #include <wayland-client.h>
+#include <wayland-util.h>
+#include "fcitx-utils/misc.h"
 #include "fcitx-utils/signals.h"
 namespace fcitx::wayland {
+
 class WlSurface;
+
 class WlTouch final {
 public:
     static constexpr const char *interface = "wl_touch";
     static constexpr const wl_interface *const wlInterface =
         &wl_touch_interface;
-    static constexpr const uint32_t version = 7;
-    typedef wl_touch wlType;
+    static constexpr const uint32_t version = 9;
+    using wlType = wl_touch;
     operator wl_touch *() { return data_.get(); }
     WlTouch(wlType *data);
     WlTouch(WlTouch &&other) noexcept = delete;
@@ -18,6 +23,7 @@ public:
     auto actualVersion() const { return version_; }
     void *userData() const { return userData_; }
     void setUserData(void *userData) { userData_ = userData; }
+
     auto &down() { return downSignal_; }
     auto &up() { return upSignal_; }
     auto &motion() { return motionSignal_; }
@@ -39,6 +45,7 @@ private:
     fcitx::Signal<void()> cancelSignal_;
     fcitx::Signal<void(int32_t, wl_fixed_t, wl_fixed_t)> shapeSignal_;
     fcitx::Signal<void(int32_t, wl_fixed_t)> orientationSignal_;
+
     uint32_t version_;
     void *userData_ = nullptr;
     UniqueCPtr<wl_touch, &destructor> data_;
@@ -46,5 +53,7 @@ private:
 static inline wl_touch *rawPointer(WlTouch *p) {
     return p ? static_cast<wl_touch *>(*p) : nullptr;
 }
+
 } // namespace fcitx::wayland
-#endif
+
+#endif // WL_TOUCH_H_
