@@ -1,18 +1,23 @@
-#ifndef ZWP_TABLET_TOOL_V2
-#define ZWP_TABLET_TOOL_V2
+#ifndef ZWP_TABLET_TOOL_V2_H_
+#define ZWP_TABLET_TOOL_V2_H_
+#include <cstdint>
 #include <wayland-client.h>
+#include <wayland-util.h>
+#include "fcitx-utils/misc.h"
 #include "fcitx-utils/signals.h"
-#include "wayland-tablet-client-protocol.h"
+#include "wayland-tablet-unstable-v2-client-protocol.h" // IWYU pragma: export
 namespace fcitx::wayland {
+
 class WlSurface;
 class ZwpTabletV2;
+
 class ZwpTabletToolV2 final {
 public:
     static constexpr const char *interface = "zwp_tablet_tool_v2";
     static constexpr const wl_interface *const wlInterface =
         &zwp_tablet_tool_v2_interface;
     static constexpr const uint32_t version = 1;
-    typedef zwp_tablet_tool_v2 wlType;
+    using wlType = zwp_tablet_tool_v2;
     operator zwp_tablet_tool_v2 *() { return data_.get(); }
     ZwpTabletToolV2(wlType *data);
     ZwpTabletToolV2(ZwpTabletToolV2 &&other) noexcept = delete;
@@ -22,6 +27,7 @@ public:
     void setUserData(void *userData) { userData_ = userData; }
     void setCursor(uint32_t serial, WlSurface *surface, int32_t hotspotX,
                    int32_t hotspotY);
+
     auto &type() { return typeSignal_; }
     auto &hardwareSerial() { return hardwareSerialSignal_; }
     auto &hardwareIdWacom() { return hardwareIdWacomSignal_; }
@@ -65,6 +71,7 @@ private:
     fcitx::Signal<void(wl_fixed_t, int32_t)> wheelSignal_;
     fcitx::Signal<void(uint32_t, uint32_t, uint32_t)> buttonSignal_;
     fcitx::Signal<void(uint32_t)> frameSignal_;
+
     uint32_t version_;
     void *userData_ = nullptr;
     UniqueCPtr<zwp_tablet_tool_v2, &destructor> data_;
@@ -72,5 +79,7 @@ private:
 static inline zwp_tablet_tool_v2 *rawPointer(ZwpTabletToolV2 *p) {
     return p ? static_cast<zwp_tablet_tool_v2 *>(*p) : nullptr;
 }
+
 } // namespace fcitx::wayland
-#endif
+
+#endif // ZWP_TABLET_TOOL_V2_H_
