@@ -1,18 +1,23 @@
-#ifndef ZWLR_DATA_CONTROL_DEVICE_V1
-#define ZWLR_DATA_CONTROL_DEVICE_V1
+#ifndef ZWLR_DATA_CONTROL_DEVICE_V1_H_
+#define ZWLR_DATA_CONTROL_DEVICE_V1_H_
+#include <cstdint>
 #include <wayland-client.h>
+#include <wayland-util.h>
+#include "fcitx-utils/misc.h"
 #include "fcitx-utils/signals.h"
-#include "wayland-wlr-data-control-unstable-v1-client-protocol.h"
+#include "wayland-wlr-data-control-unstable-v1-client-protocol.h" // IWYU pragma: export
 namespace fcitx::wayland {
+
 class ZwlrDataControlOfferV1;
 class ZwlrDataControlSourceV1;
+
 class ZwlrDataControlDeviceV1 final {
 public:
     static constexpr const char *interface = "zwlr_data_control_device_v1";
     static constexpr const wl_interface *const wlInterface =
         &zwlr_data_control_device_v1_interface;
     static constexpr const uint32_t version = 2;
-    typedef zwlr_data_control_device_v1 wlType;
+    using wlType = zwlr_data_control_device_v1;
     operator zwlr_data_control_device_v1 *() { return data_.get(); }
     ZwlrDataControlDeviceV1(wlType *data);
     ZwlrDataControlDeviceV1(ZwlrDataControlDeviceV1 &&other) noexcept = delete;
@@ -23,6 +28,7 @@ public:
     void setUserData(void *userData) { userData_ = userData; }
     void setSelection(ZwlrDataControlSourceV1 *source);
     void setPrimarySelection(ZwlrDataControlSourceV1 *source);
+
     auto &dataOffer() { return dataOfferSignal_; }
     auto &selection() { return selectionSignal_; }
     auto &finished() { return finishedSignal_; }
@@ -35,6 +41,7 @@ private:
     fcitx::Signal<void(ZwlrDataControlOfferV1 *)> selectionSignal_;
     fcitx::Signal<void()> finishedSignal_;
     fcitx::Signal<void(ZwlrDataControlOfferV1 *)> primarySelectionSignal_;
+
     uint32_t version_;
     void *userData_ = nullptr;
     UniqueCPtr<zwlr_data_control_device_v1, &destructor> data_;
@@ -43,5 +50,7 @@ static inline zwlr_data_control_device_v1 *
 rawPointer(ZwlrDataControlDeviceV1 *p) {
     return p ? static_cast<zwlr_data_control_device_v1 *>(*p) : nullptr;
 }
+
 } // namespace fcitx::wayland
-#endif
+
+#endif // ZWLR_DATA_CONTROL_DEVICE_V1_H_
