@@ -1,16 +1,20 @@
-#ifndef ZWLR_DATA_CONTROL_SOURCE_V1
-#define ZWLR_DATA_CONTROL_SOURCE_V1
+#ifndef ZWLR_DATA_CONTROL_SOURCE_V1_H_
+#define ZWLR_DATA_CONTROL_SOURCE_V1_H_
+#include <cstdint>
 #include <wayland-client.h>
+#include <wayland-util.h>
+#include "fcitx-utils/misc.h"
 #include "fcitx-utils/signals.h"
-#include "wayland-wlr-data-control-unstable-v1-client-protocol.h"
+#include "wayland-wlr-data-control-unstable-v1-client-protocol.h" // IWYU pragma: export
 namespace fcitx::wayland {
+
 class ZwlrDataControlSourceV1 final {
 public:
     static constexpr const char *interface = "zwlr_data_control_source_v1";
     static constexpr const wl_interface *const wlInterface =
         &zwlr_data_control_source_v1_interface;
     static constexpr const uint32_t version = 1;
-    typedef zwlr_data_control_source_v1 wlType;
+    using wlType = zwlr_data_control_source_v1;
     operator zwlr_data_control_source_v1 *() { return data_.get(); }
     ZwlrDataControlSourceV1(wlType *data);
     ZwlrDataControlSourceV1(ZwlrDataControlSourceV1 &&other) noexcept = delete;
@@ -20,6 +24,7 @@ public:
     void *userData() const { return userData_; }
     void setUserData(void *userData) { userData_ = userData; }
     void offer(const char *mimeType);
+
     auto &send() { return sendSignal_; }
     auto &cancelled() { return cancelledSignal_; }
 
@@ -28,6 +33,7 @@ private:
     static const struct zwlr_data_control_source_v1_listener listener;
     fcitx::Signal<void(const char *, int32_t)> sendSignal_;
     fcitx::Signal<void()> cancelledSignal_;
+
     uint32_t version_;
     void *userData_ = nullptr;
     UniqueCPtr<zwlr_data_control_source_v1, &destructor> data_;
@@ -36,5 +42,7 @@ static inline zwlr_data_control_source_v1 *
 rawPointer(ZwlrDataControlSourceV1 *p) {
     return p ? static_cast<zwlr_data_control_source_v1 *>(*p) : nullptr;
 }
+
 } // namespace fcitx::wayland
-#endif
+
+#endif // ZWLR_DATA_CONTROL_SOURCE_V1_H_
