@@ -7,9 +7,12 @@
 #ifndef _FCITX_FOCUSGROUP_P_H_
 #define _FCITX_FOCUSGROUP_P_H_
 
+#include <string>
 #include <unordered_set>
+#include <utility>
 #include <fcitx-utils/intrusivelist.h>
 #include <fcitx/focusgroup.h>
+#include "fcitx-utils/macros.h"
 
 namespace fcitx {
 
@@ -17,10 +20,10 @@ class InputContextManager;
 
 class FocusGroupPrivate : public QPtrHolder<FocusGroup> {
 public:
-    FocusGroupPrivate(FocusGroup *q, const std::string &display,
+    FocusGroupPrivate(FocusGroup *q, std::string display,
                       InputContextManager &manager)
-        : QPtrHolder(q), display_(display), manager_(manager), focus_(nullptr) {
-    }
+        : QPtrHolder(q), display_(std::move(display)), manager_(manager),
+          focus_(nullptr) {}
 
     std::string display_;
     InputContextManager &manager_;
