@@ -6,10 +6,20 @@
  */
 
 #include "globalconfig.h"
+#include <cstdint>
+#include <memory>
+#include <string>
+#include <vector>
 #include "fcitx-config/configuration.h"
+#include "fcitx-config/enum.h"
 #include "fcitx-config/iniparser.h"
 #include "fcitx-config/option.h"
+#include "fcitx-config/rawconfig.h"
+#include "fcitx-utils/eventloopinterface.h"
 #include "fcitx-utils/i18n.h"
+#include "fcitx-utils/key.h"
+#include "fcitx-utils/macros.h"
+#include "fcitx-utils/misc.h"
 #include "config.h"
 #include "inputcontextmanager.h"
 
@@ -32,7 +42,8 @@ FCITX_CONFIGURATION(
         this,
         "TriggerKeys",
         _("Trigger Input Method"),
-        {Key("Control+space"), Key("Zenkaku_Hankaku"), Key("Hangul")},
+        {isApple() ? Key("Control+Shift_L") : Key("Control+space"),
+         Key("Zenkaku_Hankaku"), Key("Hangul")},
         KeyListConstrain({KeyConstrainFlag::AllowModifierLess,
                           KeyConstrainFlag::AllowModifierOnly})};
     Option<bool> enumerateWithTriggerKeys{
@@ -131,11 +142,29 @@ FCITX_CONFIGURATION(
                                 "TogglePreedit",
                                 _("Toggle embedded preedit"),
                                 {Key("Control+Alt+P")},
-                                KeyListConstrain()};);
+                                KeyListConstrain()};
+    Option<int, IntConstrain, DefaultMarshaller<int>, ToolTipAnnotation>
+        modifierOnlyKeyTimeout{
+            this,
+            "ModifierOnlyKeyTimeout",
+            _("Time limit in milliseconds for triggering modifier key "
+              "shortcuts"),
+            250,
+            IntConstrain{-1, 5000},
+            {},
+            ToolTipAnnotation{
+                _("When using modifier only hotkey, the action may "
+                  "only be triggered if the modifier key is released within "
+                  "the timeout. -1 means there is no limit.")}};);
 
 FCITX_CONFIGURATION(
     BehaviorConfig, Option<bool> activeByDefault{this, "ActiveByDefault",
                                                  _("Active By Default")};
+    OptionWithAnnotation<PropertyPropagatePolicy,
+                         PropertyPropagatePolicyI18NAnnotation>
+        resetStateWhenFocusIn{this, "resetStateWhenFocusIn",
+                              _("Reset state on Focus In"),
+                              PropertyPropagatePolicy::No};
     OptionWithAnnotation<PropertyPropagatePolicy,
                          PropertyPropagatePolicyI18NAnnotation>
         shareState{this, "ShareInputState", _("Share Input State"),
@@ -284,6 +313,11 @@ bool GlobalConfig::activeByDefault() const {
     return d->behavior->activeByDefault.value();
 }
 
+PropertyPropagatePolicy GlobalConfig::resetStateWhenFocusIn() const {
+    FCITX_D();
+    return d->behavior->resetStateWhenFocusIn.value();
+}
+
 bool GlobalConfig::showInputMethodInformation() const {
     FCITX_D();
     return d->behavior->showInputMethodInformation.value();
@@ -389,8 +423,28 @@ int GlobalConfig::autoSavePeriod() const {
     return *d->behavior->autoSavePeriod;
 }
 
+int GlobalConfig::modifierOnlyKeyTimeout() const {
+    FCITX_D();
+    return *d->hotkey->modifierOnlyKeyTimeout;
+}
+
+bool GlobalConfig::checkModifierOnlyKeyTimeout(uint64_t lastPressedTime) const {
+    const auto timeout = modifierOnlyKeyTimeout();
+    if (timeout < 0) {
+        return true;
+    }
+    return now(CLOCK_MONOTONIC) <=
+           (lastPressedTime + static_cast<uint64_t>(timeout) * 1000ULL);
+}
+
 const Configuration &GlobalConfig::config() const {
     FCITX_D();
     return *d;
 }
+
+Configuration &GlobalConfig::config() {
+    FCITX_D();
+    return *d;
+}
+
 } // namespace fcitx
