@@ -13,17 +13,13 @@
 #include <memory>
 #include <string>
 #include <fcitx-utils/capabilityflags.h>
-#include <fcitx-utils/flags.h>
-#include <fcitx-utils/key.h>
 #include <fcitx-utils/macros.h>
 #include <fcitx-utils/rect.h>
 #include <fcitx-utils/trackableobject.h>
 #include <fcitx/event.h>
+#include <fcitx/fcitxcore_export.h>
 #include <fcitx/inputcontextproperty.h>
 #include <fcitx/surroundingtext.h>
-#include <fcitx/text.h>
-#include <fcitx/userinterface.h>
-#include "fcitxcore_export.h"
 
 /// \addtogroup FcitxCore
 /// \{
@@ -31,7 +27,7 @@
 /// \brief Input Context for Fcitx.
 
 namespace fcitx {
-typedef std::array<uint8_t, 16> ICUUID;
+using ICUUID = std::array<uint8_t, 16>;
 
 class InputContextManager;
 class FocusGroup;
@@ -180,6 +176,16 @@ public:
     /// Commit a string to the client.
     void commitString(const std::string &text);
 
+    /**
+     * Commit a string to application with a cursor location after commit.
+     *
+     * @param text text to commit
+     * @param cursor cursor position after commit, the value should be within
+     * [0, utf8::length(text)].
+     * @see CapabilityFlag::CommitStringWithCursor
+     */
+    void commitStringWithCursor(const std::string &text, size_t cursor);
+
     /// Ask client to delete a range of surrounding text.
     void deleteSurroundingText(int offset, unsigned int size);
 
@@ -364,6 +370,18 @@ private:
     FCITX_DECLARE_PRIVATE(InputContext);
 };
 
+class FCITXCORE_EXPORT InputContextV2 : public InputContext {
+    friend class InputContextPrivate;
+
+public:
+    using InputContext::InputContext;
+    ~InputContextV2() override;
+
+protected:
+    virtual void commitStringWithCursorImpl(const std::string &text,
+                                            size_t cursor) = 0;
+};
+
 /**
  * A helper class for frontend addon. It use RAII to call
  * setBlockEventToClient(true) in constructor and setBlockEventToClient(false)
