@@ -7,9 +7,8 @@
 #include "config.h"
 
 #include <fcntl.h>
-#include <signal.h>
-#include <sys/wait.h>
 #include <unistd.h>
+#include <csignal>
 #include <cstdint>
 #include <ctime>
 #include <functional>
@@ -18,10 +17,10 @@
 #include <string>
 #include <unordered_map>
 #include <utility>
-#include <fmt/format.h>
 #include <getopt.h>
 #include "fcitx-config/iniparser.h"
 #include "fcitx-utils/capabilityflags.h"
+#include "fcitx-utils/environ.h"
 #include "fcitx-utils/event.h"
 #include "fcitx-utils/eventdispatcher.h"
 #include "fcitx-utils/eventloopinterface.h"
@@ -30,25 +29,30 @@
 #include "fcitx-utils/log.h"
 #include "fcitx-utils/macros.h"
 #include "fcitx-utils/misc.h"
-#include "fcitx-utils/standardpath.h"
+#include "fcitx-utils/misc_p.h"
+#include "fcitx-utils/standardpaths.h"
 #include "fcitx-utils/stringutils.h"
 #include "fcitx-utils/utf8.h"
-#include "fcitx/event.h"
-#include "fcitx/inputmethodgroup.h"
 #include "../../modules/notifications/notifications_public.h"
 #include "addonmanager.h"
+#include "event.h"
 #include "focusgroup.h"
 #include "globalconfig.h"
 #include "inputcontextmanager.h"
 #include "inputcontextproperty.h"
 #include "inputmethodengine.h"
 #include "inputmethodentry.h"
+#include "inputmethodgroup.h"
 #include "inputmethodmanager.h"
 #include "instance.h"
 #include "instance_p.h"
 #include "misc_p.h"
 #include "userinterfacemanager.h"
 
+#ifdef HAVE_SYS_WAIT_H
+#include <sys/wait.h>
+#endif
+
 #ifdef ENABLE_X11
 #define FCITX_NO_XCB
 #include <../modules/xcb/xcb_public.h>
@@ -65,8 +69,8 @@ namespace fcitx {
 
 namespace {
 
-constexpr uint64_t AutoSaveMinInUsecs = 60ull * 1000000ull; // 30 minutes
-constexpr uint64_t AutoSaveIdleTime = 60ull * 1000000ull;   // 1 minutes
+constexpr uint64_t AutoSaveMinInUsecs = 60ULL * 1000000ULL; // 30 minutes
+constexpr uint64_t AutoSaveIdleTime = 60ULL * 1000000ULL;   // 1 minutes
 
 FCITX_CONFIGURATION(DefaultInputMethod,
                     Option<std::vector<std::string>> defaultInputMethods{
@@ -75,8 +79,9 @@ FCITX_CONFIGURATION(DefaultInputMethod,
                         this, "ExtraLayout", "ExtraLayout"};);
 
 void initAsDaemon() {
-    pid_t pid;
-    if ((pid = fork()) > 0) {
+#ifndef _WIN32
+    pid_t pid = fork();
+    if (pid > 0) {
         waitpid(pid, nullptr, 0);
         exit(0);
     }
@@ -100,6 +105,7 @@ void initAsDaemon() {
     signal(SIGTTOU, oldttou);
     signal(SIGTTIN, oldttin);
     signal(SIGCHLD, oldchld);
+#endif
 }
 
 // Switch IM when these capabilities change.
@@ -157,23 +163,23 @@ void InstanceArgument::printUsage() const {
 }
 
 InstancePrivate::InstancePrivate(Instance *q) : QPtrHolder<Instance>(q) {
-
-    const char *locale = getenv("LC_ALL");
+#ifdef ENABLE_KEYBOARD
+    auto locale = getEnvironment("LC_ALL");
     if (!locale) {
-        locale = getenv("LC_CTYPE");
+        locale = getEnvironment("LC_CTYPE");
     }
     if (!locale) {
-        locale = getenv("LANG");
+        locale = getEnvironment("LANG");
     }
     if (!locale) {
         locale = "C";
     }
-#ifdef ENABLE_KEYBOARD
+    assert(locale.has_value());
     xkbContext_.reset(xkb_context_new(XKB_CONTEXT_NO_FLAGS));
     if (xkbContext_) {
         xkb_context_set_log_level(xkbContext_.get(), XKB_LOG_LEVEL_CRITICAL);
         xkbComposeTable_.reset(xkb_compose_table_new_from_locale(
-            xkbContext_.get(), locale, XKB_COMPOSE_COMPILE_NO_FLAGS));
+            xkbContext_.get(), locale->data(), XKB_COMPOSE_COMPILE_NO_FLAGS));
         if (!xkbComposeTable_) {
             FCITX_INFO()
                 << "Trying to fallback to compose table for en_US.UTF-8";
@@ -330,14 +336,9 @@ void InstancePrivate::buildDefaultGroup() {
 
     // Load the default profile.
     auto lang = stripLanguage(getCurrentLanguage());
-    auto defaultProfile = StandardPath::global().open(
-        StandardPath::Type::PkgData, stringutils::joinPath("default", lang),
-        O_RDONLY);
-
-    RawConfig config;
     DefaultInputMethod defaultIMConfig;
-    readFromIni(config, defaultProfile.fd());
-    defaultIMConfig.load(config);
+    readAsIni(defaultIMConfig, StandardPathsType::PkgData,
+              std::filesystem::path("default") / lang);
 
     // Add extra layout from profile.
     for (const auto &extraLayout : defaultIMConfig.extraLayouts.value()) {
@@ -368,7 +369,7 @@ void InstancePrivate::buildDefaultGroup() {
         if (imLayouts.size() == 1) {
             groupName = _("Default");
         } else {
-            groupName = fmt::format(_("Group {}"), imManager_.groupCount() + 1);
+            groupName = _("Group {}", imManager_.groupCount() + 1);
         }
         imManager_.addEmptyGroup(groupName);
         groupOrders.push_back(groupName);
@@ -414,17 +415,16 @@ void InstancePrivate::showInputMethodInformation(InputContext *ic) {
         } else if (subMode.empty()) {
             display = std::move(name);
         } else {
-            display = fmt::format(_("{0} ({1})"), name, subMode);
+            display = _("{0} ({1})", name, subMode);
         }
     } else if (entry) {
-        display = fmt::format(_("{0} (Not available)"), entry->name());
+        display = _("{0} (Not available)", entry->name());
     } else {
         display = _("(Not available)");
     }
     if (!globalConfig_.compactInputMethodInformation() &&
         imManager.groupCount() > 1) {
-        display = fmt::format(_("Group {0}: {1}"),
-                              imManager.currentGroup().name(), display);
+        display = _("Group {0}: {1}", imManager.currentGroup().name(), display);
     }
     inputState->showInputMethodInformation(display);
 }
@@ -460,8 +460,8 @@ void InstancePrivate::navigateGroup(InputContext *ic, const Key &key,
         notifications_->call<INotifications::showTip>(
             "enumerate-group", _("Input Method"), "input-keyboard",
             _("Switch group"),
-            fmt::format(_("Switch group to {0}"),
-                        imManager_.groups()[inputState->pendingGroupIndex_]),
+            _("Switch group to {0}",
+              imManager_.groups()[inputState->pendingGroupIndex_]),
             3000);
     }
 }
@@ -689,8 +689,8 @@ Instance::Instance(int argc, char **argv) {
                     d->notifications_->call<INotifications::showTip>(
                         "enumerate-group", _("Input Method"), "input-keyboard",
                         _("Switch group"),
-                        fmt::format(_("Switched group to {0}"),
-                                    d->imManager_.currentGroup().name()),
+                        _("Switched group to {0}",
+                          d->imManager_.currentGroup().name()),
                         3000);
                 }
                 d->lastGroup_ = newGroup;
@@ -1341,6 +1341,9 @@ void InstanceArgument::parseOption(int argc, char **argv) {
 }
 
 void Instance::setSignalPipe(int fd) {
+#ifdef _WIN32
+    FCITX_UNUSED(fd);
+#else
     FCITX_D();
     d->signalPipe_ = fd;
     d->signalPipeEvent_ = d->eventLoop_.addIOEvent(
@@ -1348,6 +1351,7 @@ void Instance::setSignalPipe(int fd) {
             handleSignal();
             return true;
         });
+#endif
 }
 
 bool Instance::willTryReplace() const {
@@ -1366,6 +1370,7 @@ bool Instance::exiting() const {
 }
 
 void Instance::handleSignal() {
+#ifndef _WIN32
     FCITX_D();
     uint8_t signo = 0;
     while (fs::safeRead(d->signalPipe_, &signo, sizeof(signo)) > 0) {
@@ -1379,6 +1384,7 @@ void Instance::handleSignal() {
             d->zombieReaper_->setOneShot();
         }
     }
+#endif
 }
 
 void Instance::initialize() {
@@ -1427,6 +1433,7 @@ void Instance::initialize() {
             }
             return false;
         });
+#ifndef _WIN32
     d->zombieReaper_ = d->eventLoop_.addTimeEvent(
         CLOCK_MONOTONIC, now(CLOCK_MONOTONIC), 0,
         [](EventSourceTime *, uint64_t) {
@@ -1436,6 +1443,7 @@ void Instance::initialize() {
             return false;
         });
     d->zombieReaper_->setEnabled(false);
+#endif
 
     d->exitEvent_ = d->eventLoop_.addExitEvent([this](EventSource *) {
         FCITX_DEBUG() << "Running save...";
@@ -1930,7 +1938,8 @@ std::string Instance::addonForInputMethod(const std::string &imName) {
 }
 
 void Instance::configure() {
-    startProcess({StandardPath::fcitxPath("bindir", "fcitx5-configtool")});
+    startProcess(
+        {StandardPaths::fcitxPath("bindir", "fcitx5-configtool").string()});
 }
 
 void Instance::configureAddon(const std::string &) {}
@@ -1986,12 +1995,8 @@ void Instance::refresh() {
 
 void Instance::reloadConfig() {
     FCITX_D();
-    const auto &standardPath = StandardPath::global();
-    auto file =
-        standardPath.open(StandardPath::Type::PkgConfig, "config", O_RDONLY);
-    RawConfig config;
-    readFromIni(config, file.fd());
-    d->globalConfig_.load(config);
+    readAsIni(d->globalConfig_.config(), StandardPathsType::PkgConfig,
+              "config");
     FCITX_DEBUG() << "Trigger Key: "
                   << Key::keyListToString(d->globalConfig_.triggerKeys());
     d->icManager_.setPropertyPropagatePolicy(
