@@ -11,10 +11,9 @@
 #include <ostream>
 #include <string>
 #include <vector>
-#include <fcitx-utils/flags.h>
 #include <fcitx-utils/macros.h>
 #include <fcitx-utils/textformatflags.h>
-#include "fcitxcore_export.h"
+#include <fcitx/fcitxcore_export.h>
 
 /// \addtogroup FcitxCore
 /// \{
@@ -38,6 +37,13 @@ public:
     void setCursor(int pos = -1);
     void clear();
     void append(std::string str, TextFormatFlags flag = TextFormatFlag::NoFlag);
+    /**
+     * Append another text.
+     *
+     * @param text text to append
+     * @since 5.1.9
+     */
+    void append(Text text);
     const std::string &stringAt(int idx) const;
     TextFormatFlags formatAt(int idx) const;
     size_t size() const;
