@@ -5,20 +5,23 @@
  *
  */
 
-#include <locale.h>
 #include <sys/stat.h>
+#include <clocale>
 #include <cstdio>
 #include <cstdlib>
 #include <exception>
+#include <filesystem>
 #include <iostream>
 #include <string>
 #include <utility>
 #include <vector>
+#include "fcitx-utils/environ.h"
 #include "fcitx-utils/fs.h"
 #include "fcitx-utils/log.h"
 #include "fcitx-utils/misc.h"
 #include "fcitx-utils/misc_p.h"
 #include "fcitx-utils/standardpath.h"
+#include "fcitx-utils/standardpaths.h"
 #include "fcitx-utils/stringutils.h"
 #include "fcitx/addonfactory.h"
 #include "fcitx/addoninstance.h"
@@ -29,7 +32,7 @@
 
 using namespace fcitx;
 int selfpipe[2];
-std::string crashlog;
+std::filesystem::path crashlog;
 
 FCITX_DEFINE_STATIC_ADDON_REGISTRY(getStaticAddon)
 #ifdef ENABLE_KEYBOARD
@@ -39,22 +42,23 @@ FCITX_IMPORT_ADDON_FACTORY(getStaticAddon, keyboard);
 int main(int argc, char *argv[]) {
     umask(077);
     StandardPath::global().syncUmask();
+    StandardPaths::global().syncUmask();
     if (safePipe(selfpipe) < 0) {
         fprintf(stderr, "Could not create self-pipe.\n");
         return 1;
     }
 
-    auto *home = getenv("HOME");
-    if (!home || home[0] == '\0') {
+    auto home = getEnvironment("HOME");
+    if (!home || home->empty()) {
         fprintf(stderr, "Please set HOME.\n");
         return 1;
     }
 
     auto userDir =
-        StandardPath::global().userDirectory(StandardPath::Type::PkgConfig);
+        StandardPaths::global().userDirectory(StandardPathsType::PkgConfig);
     if (!userDir.empty()) {
         if (fs::makePath(userDir)) {
-            crashlog = stringutils::joinPath(userDir, "crash.log");
+            crashlog = userDir / "crash.log";
         }
     }
 
@@ -86,9 +90,11 @@ int main(int argc, char *argv[]) {
         std::vector<std::string> args;
         if (isInFlatpak()) {
             args = {"flatpak-spawn",
-                    StandardPath::fcitxPath("bindir", "fcitx5"), "-rd"};
+                    StandardPaths::fcitxPath("bindir", "fcitx5").string(),
+                    "-rd"};
         } else {
-            args = {StandardPath::fcitxPath("bindir", "fcitx5"), "-r"};
+            args = {StandardPaths::fcitxPath("bindir", "fcitx5").string(),
+                    "-r"};
         }
         startProcess(args);
     }
