@@ -6,16 +6,28 @@
  */
 
 #include "waylandshmwindow.h"
+#include <cstdint>
+#include <iterator>
+#include <memory>
+#include <cairo.h>
+#include "fcitx-utils/eventloopinterface.h"
+#include "buffer.h"
 #include "common.h"
+#include "waylandui.h"
+#include "waylandwindow.h"
+#include "wl_shm.h"
 
 namespace fcitx::classicui {
 
 namespace {
 
-void surfaceToBufferSize(int32_t buffer_scale, uint32_t *width,
+void surfaceToBufferSize(unsigned int buffer_scale, uint32_t *width,
                          uint32_t *height) {
-    *width *= buffer_scale;
-    *height *= buffer_scale;
+    // round (size * scale), but all integer calculation.
+    *width = (*width * buffer_scale + (WaylandWindow::ScaleDominator / 2)) /
+             WaylandWindow::ScaleDominator;
+    *height = (*height * buffer_scale + (WaylandWindow::ScaleDominator / 2)) /
+              WaylandWindow::ScaleDominator;
 }
 
 } // namespace
@@ -65,8 +77,9 @@ cairo_surface_t *WaylandShmWindow::prerender() {
         }
     }
 
-    uint32_t bufferWidth = width_, bufferHeight = height_;
-    surfaceToBufferSize(scale_, &bufferWidth, &bufferHeight);
+    uint32_t bufferWidth = width_;
+    uint32_t bufferHeight = height_;
+    surfaceToBufferSize(bufferScale(), &bufferWidth, &bufferHeight);
 
     if (iter != buffers_.end() && ((*iter)->width() != bufferWidth ||
                                    (*iter)->height() != bufferHeight)) {
@@ -104,7 +117,16 @@ void WaylandShmWindow::render() {
         return;
     }
 
-    buffer_->attachToSurface(surface_.get(), scale_);
+    if (viewport_) {
+        if (buffer_->attachToSurface(surface_.get(), 1)) {
+            viewport_->setDestination(width_, height_);
+            surface_->commit();
+        }
+    } else {
+        if (buffer_->attachToSurface(surface_.get(), lastOutputScale_)) {
+            surface_->commit();
+        }
+    }
 }
 
 void WaylandShmWindow::hide() {
