@@ -5,10 +5,10 @@
  *
  */
 #include "testfrontend.h"
-#include <fcitx/addonfactory.h>
-#include <fcitx/addonmanager.h>
-#include <fcitx/inputcontextmanager.h>
-#include <fcitx/inputpanel.h>
+#include "fcitx/addonfactory.h"
+#include "fcitx/addonmanager.h"
+#include "fcitx/inputcontextmanager.h"
+#include "fcitx/inputpanel.h"
 
 namespace fcitx {
 
@@ -106,4 +106,4 @@ public:
 
 } // namespace fcitx
 
-FCITX_ADDON_FACTORY(fcitx::TestFrontendFactory);
+FCITX_ADDON_FACTORY_V2(testfrontend, fcitx::TestFrontendFactory);
